@@ -1,5 +1,4 @@
 import unittest
-import time
 import datetime
 import copy
 import logging
@@ -8,8 +7,8 @@ import sys
 import interface
 
 
-from _dd_testcase_util import merge_struct, log1, log2, log3, build_path, get, post
-from _dd_testcase_util import log_js_example, is_compatible_json, deal_with_output_response_data
+from _dd_testcase_util import merge_struct, log1, log3, log_js_example, go_route
+from _dd_testcase_util import is_compatible_json, deal_with_output_response_data
 
 log = logging.getLogger(__name__)
 log.setLevel(logging.INFO)
@@ -51,22 +50,6 @@ class DocDrivenTestCase(unittest.TestCase):
         for route in route_list:
             cls.run_route(route, full_chapter_config, full_chapter_predict)
 
-    @classmethod
-    def go_route(cls, route, config):
-        route.report_stamp('FAIL', 1, datetime.datetime.now(), speed=0.0)
-        path = build_path(route.title, config)
-        start_time = None
-        result = {}
-        if config.get('post'): # will return None if json has null for this key
-            start_time = time.time()
-            result = post(path, config['post'], DocDrivenTestCase.default_base_url, DocDrivenTestCase.default_http_headers)
-            speed = time.time() - start_time
-        else:
-            start_time = time.time()
-            result = cls.GET(path)
-            speed = time.time() - start_time
-        return result, speed
-
     @classmethod
     def run_route(cls, route, full_ch_config, full_ch_predict):
         full_config = copy.deepcopy(full_ch_config)
@@ -82,7 +65,7 @@ class DocDrivenTestCase(unittest.TestCase):
         log_string = ''
         log_string += log1(route, full_config, full_predict)
 
-        result, speed_in_sec = cls.go_route(route, full_config)
+        result, speed_in_sec = go_route(route, full_config)
 
         if result.status_code>=200 and result.status_code<300:
             log.debug('got report code 2xx')
@@ -143,4 +126,12 @@ class DocDrivenTestCase(unittest.TestCase):
             log.debug('finished running route list for chapter: '+chp.title)
         return test_method
 
+    @classmethod
+    def remove_test_methods(cls):
+        test_methods = []
+        for name in vars(cls):
+            if name.startswith("test_") and callable(getattr(cls, name)):
+                test_methods.append(name)
+        for test_method in test_methods:
+            delattr(cls, test_method)
 
