@@ -4,6 +4,9 @@ import datetime
 import interface
 import types
 import logging
+import time
+
+import testcase
 
 log = logging.getLogger(__name__)
 
@@ -15,6 +18,21 @@ def post(path, data, base_url, http_headers):
         data = json.dumps(data)
     return requests.post(base_url+path, data=data, headers=http_headers)
 
+def go_route(route, config):
+    route.report_stamp('FAIL', 1, datetime.datetime.now(), speed=0.0)
+    path = build_path(route.title, config)
+    start_time = None
+    result = {}
+    if config.get('post'): # will return None if json has null for this key
+        start_time = time.time()
+        result = post(path, config['post'], testcase.default_base_url, testcase.default_http_headers)
+        speed = time.time() - start_time
+    else:
+        start_time = time.time()
+        result = get(path, testcase.default_base_url, testcase.default_http_headers)
+        speed = time.time() - start_time
+    return result, speed
+
 def merge_struct(base, local):
     if base is None:
         if local is not None:
